==> ilias-3.10.9.tbz: www/ilias/Services/Search/classes/Like/class.ilLikeUserSearch.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2001 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/

/**
* Class ilLikeUserSearch
*
* Performs Mysql Like search in table usr_data
*
* @author Stefan Meyer <smeyer@databay.de>
* @version $Id: class.ilLikeUserSearch.php 16898 2008-07-07 07:41:55Z smeyer $
* 
* @package ilias-search
*
*/
include_once 'Services/Search/classes/class.ilUserSearch.php';

class ilLikeUserSearch extends ilUserSearch
{

	/**
	* Constructor
	* @access public
	*/
	function ilLikeUserSearch(&$qp_obj)
	{
		parent::ilUserSearch($qp_obj);
	}


	function __createWhereCondition()
	{
		$fields = $this->getFields();
		$field = $fields[0].' ';

		$and = "  WHERE ( ";
		
		$counter = 0;
		foreach($this->query_parser->getQuotedWords() as $word)
		{
			if($counter++)
			{
				$and .= " OR ";
			}
			$and .= $field;

			if(strpos($word,'^') === 0)
			{
				$and .= ("LIKE ('".substr($word,1)."%')");
			}
			else
			{
				$and .= ("LIKE ('%".$word."%')");
			}
		}
		
		return $and.") ";
	}
}
?>

==> ilias-4.3.2.tbz: www/ilias/Services/Search/classes/Like/class.ilLikeUserSearch.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2001 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/

/**
* Class ilLikeUserSearch
*
* Performs Mysql Like search in table usr_data
*
* @author Stefan Meyer <meyer@leifos.com>
* @version $Id: class.ilLikeUserSearch.php 23143 2010-03-09 12:15:33Z smeyer $
* 
* @package ilias-search
*
*/
include_once 'Services/Search/classes/class.ilUserSearch.php';

class ilLikeUserSearch extends ilUserSearch
{

	/**
	* Constructor
	* @access public
	*/
	function ilLikeUserSearch(&$qp_obj)
	{
		parent::ilUserSearch($qp_obj);
	}


	function __createWhereCondition()
	{
		global $ilDB;
		
		$fields = $this->getFields();
		$field = $fields[0].' ';

		$and = "  WHERE ( ";
		
		$counter = 0;
		foreach($this->query_parser->getQuotedWords() as $word)
		{
			if($counter++)
			{
				$and .= " OR ";
			}
			
			#$and .= $field;

			if(strpos($word,'^') === 0)
			{
				$and .= $ilDB->like($field,'text',substr($word,1).'%');
				#$and .= ("LIKE ('".substr($word,1)."%')");
			}
			else
			{
				$and .= $ilDB->like($field,'text','%'.$word.'%');
				#$and .= ("LIKE ('%".$word."%')");
			}
		}
		
		return $and.") ";
	}
}
?>
